<?php

namespace Drupal\jfu\Plugin\Field\FieldFormatter;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Field\FormatterBase;
use Drupal\Component\Serialization\Json;

/**
 * Plugin implementation of the 'json_component_formatter' formatter.
 *
 * @FieldFormatter(
 *   id = "json_component_formatter",
 *   label = @Translation("Components"),
 *   field_types = {
 *     "json",
 *     "json_native",
 *     "json_native_binary",
 *   },
 * )
 */

class JSONComponentFormatter extends FormatterBase {
  public function settingsForm(array $form, FormStateInterface $form_state) {
    $form['text_length'] = [
      '#title' => $this->t('Text length'),
      '#type' => 'select',
      '#options' => [
        'short' => $this->t('Short'),
        'long' => $this->t('Long'),
      ],
      '#default_value' => $this->getSetting('text_length'),
    ];
  
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function settingsSummary() {
    $summary = [];
    $summary[] = $this->t('Displays all components.');
    return $summary;
  }

  /**
   * {@inheritdoc}
   */
  public function viewElements(FieldItemListInterface $items, $langcode) {
    $elements = [];
    $json_array = [];

    $json_type_array = '';

    foreach ($items as $key=>$item) {
      $json_array[$key] = Json::decode($item->value);

      $json_type_array = $json_array[$key];
      $elements[] = array(
        '#theme' => 'json_widget_component',
        '#values' => $json_array,
        '#json_array' => $json_type_array,
      );
    }

    return $elements;
  }
}
